==> 0.3.19.tar.gz: android/src/main/java/com/samelement/iot_notification/service/AccessTokenRepository.java <==
package com.samelement.iot_notification.service;

import android.content.Context;
import android.content.SharedPreferences;

import androidx.preference.PreferenceManager;

import com.samelement.iot_notification.screen.IntentKey;
import com.samelement.iot_notification.util.EncryptUtil;

import java.io.IOException;
import java.util.Calendar;
import java.util.Date;

import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;

public class AccessTokenRepository {
    private SharedPreferences sharedPreferences;
    private Context context;
    private static AccessTokenRepository instance;

    private AccessTokenRepository(Context context) {
        this.context = context;
        sharedPreferences = PreferenceManager.getDefaultSharedPreferences(context);
    }

    public static AccessTokenRepository getInstance(Context context) {
        if (instance == null)
            instance = new AccessTokenRepository(context);

        return instance;
    }

    public String getUserAccessToken() {
        return EncryptUtil.getInstance(context).decrypt(sharedPreferences.getString(IntentKey.KEY_USER_ACCESS_TOKEN, "invalid-token"));
    }

    public String getUserRefreshToken() {
        return EncryptUtil.getInstance(context).decrypt(sharedPreferences.getString(IntentKey.KEY_USER_REFRESH_TOKEN, "invalid-token"));
    }

    public String getDevAccessToken() {
        return EncryptUtil.getInstance(context).decrypt(sharedPreferences.getString(IntentKey.KEY_DEV_ACCESS_TOKEN, "invalid-token"));
    }

    public String getDevRefreshToken() {
        return EncryptUtil.getInstance(context).decrypt(sharedPreferences.getString(IntentKey.KEY_DEV_REFRESH_TOKEN, "invalid-token"));
    }

    public String refreshDevAccessToken() {
        final String apiHost = sharedPreferences.getString(IntentKey.KEY_API_HOST, "no-host");
        final String devRefreshToken = getDevRefreshToken();

        OkHttpClient client = new OkHttpClient.Builder()
                .build();

        Request request = new Request.Builder()
                .get()
                .addHeader(IntentKey.KEY_API_PARAM, devRefreshToken)
                .url(apiHost + "/auth")
                .build();

        try (Response response = client.newCall(request).execute()) {
            if (response.isSuccessful()) {
                String newDevAccessToken = response.body().string();
                updateDevTokens(newDevAccessToken, devRefreshToken);

                return newDevAccessToken;
            }
        } catch (IOException e) {
            e.printStackTrace();
        }

        return null;
    }

    public String refreshUserAccessToken() {
        final String apiHost = sharedPreferences.getString(IntentKey.KEY_API_HOST, "no-host");
        final String devAccessToken = getDevAccessToken();

        OkHttpClient client = new OkHttpClient.Builder()
                .build();

        final String userRefreshToken = getUserRefreshToken();
        Request request = new Request.Builder()
                .get()
                .addHeader(IntentKey.KEY_AUTH, "Bearer " + userRefreshToken)
                .addHeader(IntentKey.KEY_API_PARAM, devAccessToken)
                .url(apiHost + "/auth")
                .build();

        try (Response response = client.newCall(request).execute()) {
            if (response.isSuccessful()) {
                String newUserAccessToken = response.body().string();
                updateUserTokens(newUserAccessToken, userRefreshToken);
                return newUserAccessToken;
            }
        } catch (IOException e) {
            e.printStackTrace();
        }

        return null;
    }

    private void updateUserTokens(String newAccessToken, String newRefreshToken) {
        String encodedAccessToken = EncryptUtil.getInstance(context).encrypt(newAccessToken);
        String encodedRefreshToken = EncryptUtil.getInstance(context).encrypt(newRefreshToken);

        updateTokenExpired();

        sharedPreferences.edit()
                .putString(IntentKey.KEY_USER_ACCESS_TOKEN, encodedAccessToken)
                .putString(IntentKey.KEY_USER_REFRESH_TOKEN, encodedRefreshToken).apply();
    }

    private void updateDevTokens(String newAccessToken, String newRefreshToken) {
        String encodedAccessToken = EncryptUtil.getInstance(context).encrypt(newAccessToken);
        String encodedRefreshToken = EncryptUtil.getInstance(context).encrypt(newRefreshToken);

        sharedPreferences.edit()
                .putString(IntentKey.KEY_DEV_ACCESS_TOKEN, encodedAccessToken)
                .putString(IntentKey.KEY_DEV_REFRESH_TOKEN, encodedRefreshToken).apply();
    }

    public void updateTokenExpired() {
        SharedPreferences preferences = PreferenceManager.getDefaultSharedPreferences(context);
        Date currentDate = new Date();
        long issuedAt = currentDate.getTime();
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(currentDate);
        calendar.add(Calendar.MINUTE, 705); // add 11.75 hours

        long expiredAt = calendar.getTimeInMillis();

        preferences.edit()
                .putLong(IntentKey.KEY_TOKEN_ISSUED_AT, issuedAt)
                .putLong(IntentKey.KEY_TOKEN_EXPIRED_AT, expiredAt).apply();
    }
}

==> 0.4.3.tar.gz: android/src/main/java/com/samelement/iot_notification/service/AccessTokenRepository.java <==
package com.samelement.iot_notification.service;

import android.content.Context;
import android.content.SharedPreferences;
import androidx.preference.PreferenceManager;

import com.samelement.iot_notification.screen.IntentKey;
import com.samelement.iot_notification.util.EncryptUtil;

import java.io.IOException;
import java.util.Calendar;
import java.util.Date;

import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;

public class AccessTokenRepository {
    private final SharedPreferences sharedPreferences;
    private final Context context;
    private static AccessTokenRepository instance;

    private AccessTokenRepository(Context context) {
        this.context = context;
        sharedPreferences = PreferenceManager.getDefaultSharedPreferences(context);
    }

    public static AccessTokenRepository getInstance(Context context) {
        if (instance == null)
            instance = new AccessTokenRepository(context);

        return instance;
    }

    public String getUserAccessToken() {
        return EncryptUtil.getInstance(context).decrypt(sharedPreferences.getString(IntentKey.KEY_USER_ACCESS_TOKEN, "invalid-token"));
    }

    public String getUserRefreshToken() {
        return EncryptUtil.getInstance(context).decrypt(sharedPreferences.getString(IntentKey.KEY_USER_REFRESH_TOKEN, "invalid-token"));
    }

    public String getDevAccessToken() {
        return EncryptUtil.getInstance(context).decrypt(sharedPreferences.getString(IntentKey.KEY_DEV_ACCESS_TOKEN, "invalid-token"));
    }

    public String getDevRefreshToken() {
        return EncryptUtil.getInstance(context).decrypt(sharedPreferences.getString(IntentKey.KEY_DEV_REFRESH_TOKEN, "invalid-token"));
    }

    public String refreshDevAccessToken() {
        final String apiHost = sharedPreferences.getString(IntentKey.KEY_API_HOST, "no-host");
        final String devRefreshToken = getDevRefreshToken();

        OkHttpClient client = new CustomTrust(context).getClient();

        Request request = new Request.Builder()
                .get()
                .addHeader(IntentKey.KEY_API_PARAM, devRefreshToken)
                .url(apiHost + "/auth")
                .build();

        try (Response response = client.newCall(request).execute()) {
            if (response.isSuccessful()) {
                String newDevAccessToken = response.body().string();

                updateDevTokens(newDevAccessToken, devRefreshToken);

                return newDevAccessToken;
            }
        } catch (IOException e) {
            e.printStackTrace();
        }

        return null;
    }

    public String refreshUserAccessToken() {
        final String apiHost = sharedPreferences.getString(IntentKey.KEY_API_HOST, "no-host");
        final String devAccessToken = getDevAccessToken();

        OkHttpClient client = new CustomTrust(context).getClient();

        final String userRefreshToken = getUserRefreshToken();
        Request request = new Request.Builder()
                .get()
                .addHeader(IntentKey.KEY_AUTH, "Bearer " + userRefreshToken)
                .addHeader(IntentKey.KEY_API_PARAM, devAccessToken)
                .url(apiHost + "/auth")
                .build();

        try (Response response = client.newCall(request).execute()) {
            if (response.isSuccessful()) {
                String newUserAccessToken = response.body().string();
                updateUserTokens(newUserAccessToken, userRefreshToken);
                return newUserAccessToken;
            }
        } catch (IOException e) {
            e.printStackTrace();
        }

        return null;
    }

    private void updateUserTokens(String newAccessToken, String newRefreshToken) {
        String encodedAccessToken = EncryptUtil.getInstance(context).encrypt(newAccessToken);
        String encodedRefreshToken = EncryptUtil.getInstance(context).encrypt(newRefreshToken);

        updateTokenExpired();

        sharedPreferences.edit()
                .putString(IntentKey.KEY_USER_ACCESS_TOKEN, encodedAccessToken)
                .putString(IntentKey.KEY_USER_REFRESH_TOKEN, encodedRefreshToken).apply();
    }

    private void updateDevTokens(String newAccessToken, String newRefreshToken) {
        String encodedAccessToken = EncryptUtil.getInstance(context).encrypt(newAccessToken);
        String encodedRefreshToken = EncryptUtil.getInstance(context).encrypt(newRefreshToken);

        sharedPreferences.edit()
                .putString(IntentKey.KEY_DEV_ACCESS_TOKEN, encodedAccessToken)
                .putString(IntentKey.KEY_DEV_REFRESH_TOKEN, encodedRefreshToken).apply();
    }

    public void updateTokenExpired() {
        SharedPreferences preferences = PreferenceManager.getDefaultSharedPreferences(context);
        Date currentDate = new Date();
        long issuedAt = currentDate.getTime();
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(currentDate);
        calendar.add(Calendar.MINUTE, 705); // add 11.75 hours

        long expiredAt = calendar.getTimeInMillis();

        preferences.edit()
                .putLong(IntentKey.KEY_TOKEN_ISSUED_AT, issuedAt)
                .putLong(IntentKey.KEY_TOKEN_EXPIRED_AT, expiredAt).apply();
    }
}
